{% extends "base.html" %}

{% block content %}
	<div class="special_links">
		<a href="?ascii">plain text</a>, 
		<a href="?bibtex">BibTex</a>
	</div>
	{% for publication in publications %}
		<h1>Publication</h1>
		<hr/>
		<div style="margin-bottom: 30px;">
		{% include "publications/publication.html" %}<br/>
		</div>
		<h1>Reference</h1>
		<hr/>
		<pre lang="bibtex">{% include "publications/publication.bib" %}</pre>
	{% endfor %}
{% endblock %}
