<?xml version="1.1" encoding="utf-8"?> 
<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.1//EN"
                      "http://www.w3.org/TR/xhtml11/DTD/xhtml11.dtd">
<html xmlns="http://www.w3.org/1999/xhtml">
	<head>
		{% block head %}<title>django-publications</title>{% endblock %}
		<style type="text/css">
			body {
				font-family: "Hiragino Sans GB", "Helvetica Neue", "Lucida Grande", Helvetica, Arial, sans-serif;
				font-size: 10pt;
				line-height: 14pt;
				padding: 20px;
			}

			h1 {
				font-size: 14pt;
				font-weight: normal;
				line-height: 24pt;
				margin: 0px;
				padding: 0px;
				color: #aaa;
			}

			h2 {
				font-size: 14pt;
				font-weight: bold;
			}

			a {
				text-decoration: none;
				color: #999;
			}

			.special_links {
				vertical-align: middle;
				float: right;
				text-align: right;
			}

			.special_links a {
				line-height: 24pt;
				vertical-align: middle;
			}

			a.author, a.title {
				color: black;
			}

			a.keyword {
				color: #777;
				background: #ddd;
				padding: 2px 4px;
				font-size: 9pt;
				line-height: 18pt;
				text-shadow: #eee 0px 1px 0px;

				border-bottom: 1px solid #aaa;
				border-right: 1px solid #ccc;

				border-radius: 4px;
				-moz-border-radius: 4px;
				-webkit-border-radius: 4px;
			}

			a.keyword:hover {
				color: #666;
				background: #ccc;
			}

			hr {
				border: 0px;
				border-top: 1px solid #ddd;
				margin: 5px 0px 15px;
				height: 0px;
				padding: 0px;
			}

			pre {
				white-space: pre-wrap;
				white-space: -moz-pre-wrap !important;
				white-space: -pre-wrap;
				white-space: -o-pre-wrap;
				word-wrap: break-word;
			}
		</style>
	</head>
	<body>
		{% block content %}
		{% endblock %}
	</body>
</html>
