{% extends "base.html" %}

{% block head %}
	{{ block.super }}
	<link rel="alternate" type="application/rss+xml" title="RSS" href="?rss" />
{% endblock %}

{% block content %}
	{% if publications %}
		<div class="special_links">
			<a href="?ascii">plain text</a>, 
			<a href="?bibtex">BibTex</a>
		</div>
		{% for type in types %}
			<h1>{{ type.description }}{% if forloop.first %} by {{ author }}{% endif %}</h1>
			<hr/>
			<div{% if not forloop.last %} style="margin-bottom: 30px;"{% endif %}>
				{% for publication in type.publications %}
					<div{% if not forloop.last %} style="margin-bottom: 20px;"{% endif %}>
						{% include "publications/publication.html" %}
					</div>
				{% endfor %}
			</div>
		{% endfor %}
	{% else %}
		<h2>Sorry,</h2>
		no publications found for {{ author }}.
	{% endif %}
{% endblock %}
