{% extends "base.html" %}

{% block content %}
	{% if publications %}
		<div class="special_links">
			<a href="?ascii">plain text</a>, 
			<a href="?bibtex">BibTex</a>
		</div>
		<h1>Publications with the keyword &quot;{{ keyword }}&quot;</h1>
		<hr/>
		{% for publication in publications %}
			<div{% if not forloop.last %} style="margin-bottom: 20px;"{% endif %}>
				{% include "publications/publication.html" %}
			</div>
		{% endfor %}
	{% else %}
		<h2>Sorry,</h2>
		no publications found with the keyword &quot;{{ keyword }}&quot;.
	{% endif %}
{% endblock %}
