{% extends "base.html" %}

{% block head %}
	{{ block.super }}
	<link rel="alternate" type="application/rss+xml" title="RSS" href="?rss" />
{% endblock %}

{% block content %}
	<div class="special_links">
		<a href="?ascii">plain text</a>, 
		<a href="?bibtex">BibTex</a>
	</div>
	{% for year, publications in years %}
		<a href="/publications/year/{{ year }}/"><h1>{{ year }}</h1></a>
		<hr/>
		<div{% if not forloop.last %} style="margin-bottom: 30px;"{% endif %}>
		{% for publication in publications %}
			<div{% if not forloop.last %} style="margin-bottom: 20px;"{% endif %}>
				{% include "publications/publication.html" %}
			</div>
		{% endfor %}
		</div>
	{% endfor %}
{% endblock %}
